<?php
/*
 * Version: 1.1.5
 */



if (!class_exists('oftnPremium')) {

	class oftnPremium {

        public static $plugin_name = 'Options for Twenty Nineteen';
        public static $plugin_prefix = 'oftn';
        public static $plugin_text_domain = 'options-for-twenty-nineteen';

		public static function plugin_version() {

            return options_for_twenty_nineteen_premium_class::$version;

        }

        private static $timeout = 30;

		public static function plugin_common_class() {

            return str_replace('Premium', 'Common', get_called_class());

		}

		public static function check_plugin_update($transient) {

            $plugin_to_check = self::plugin_to_check();

            if (isset($transient->checked)) {

                $url = add_query_arg(
                    array(
                        'action' => 'plugin_version',
                        'plugin' => $plugin_to_check['slug'],
                        'version' => self::plugin_version(),
                        'purchased' => get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased'),
                        'trial_date' => get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date'),
                        'url' => ((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'])
                    ),
                    'https://webd.uk/wp-admin/admin-ajax.php'
                );

                $response = wp_remote_request($url, array('timeout' => self::$timeout));

                if(!is_wp_error($response) && isset($response['response']['code']) && $response['response']['code'] == 200 && isset($response['body'])) {

                    $plugin_version = json_decode($response['body']);

                    if (isset($plugin_version->trial_date) && isset($plugin_version->purchased)) {

                        self::premium_check($plugin_version->trial_date, $plugin_version->purchased);

                    }

                    if (is_object($plugin_version) && isset($plugin_version->new_version) && isset($plugin_version->tested) && isset($plugin_version->changelog) && version_compare(preg_replace("/[^0-9.]/", '', $plugin_version->new_version), $plugin_to_check['version'], '>')) {

                        $plugin_update = new stdClass();
                        $plugin_update->id = 'webd.uk/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '/';
                        $plugin_update->slug = $plugin_to_check['slug'];
                        $plugin_update->plugin = $plugin_to_check['plugin'];
                        $plugin_update->new_version = preg_replace("/[^0-9.]/", '', $plugin_version->new_version);
                        $plugin_update->url = 'https://' . $plugin_update->id;
                        $plugin_update->package = 'https://webd.uk/downloads/' . $plugin_to_check['slug'] . '.' . $plugin_update->new_version . '.zip';

                        if ($plugin_to_check['hosted']) {

                            $plugin_update->icons = array(
                                '2x' => 'https://ps.w.org/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '/assets/icon-256x256.jpg',
                                '1x' => 'https://ps.w.org/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '/assets/icon-128x128.jpg'
                            );
            
                        }
            
                        $plugin_update->tested = preg_replace("/[^0-9.]/", '', $plugin_version->tested);
                        $plugin_update->upgrade_notice = sanitize_text_field($plugin_version->changelog);
                        $transient->response[$plugin_to_check['plugin']] = $plugin_update;  

                    }

                }

            }

            return $transient;
        }

		public static function get_plugin_information($result, $action, $args) {

            $plugin_to_check = self::plugin_to_check();

            if ($action == 'plugin_information' && isset($args->slug) && $args->slug == $plugin_to_check['slug']) {

                $url = add_query_arg(
                    array(
                        'action' => 'plugin_information',
                        'plugin' => $plugin_to_check['slug'],
                        'version' => self::plugin_version(),
                        'purchased' => get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased'),
                        'trial_date' => get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date'),
                        'url' => ((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'])
                    ),
                    'https://webd.uk/wp-admin/admin-ajax.php'
                );
                $response = wp_remote_request($url, array('timeout' => self::$timeout));

                if(!is_wp_error($response) && isset($response['response']['code']) && $response['response']['code'] == 200 && isset($response['body'])) {

                    $plugin_information = json_decode($response['body']);

                    if (isset($plugin_information->trial_date) && isset($plugin_information->purchased)) {

                        self::premium_check($plugin_information->trial_date, $plugin_information->purchased);

                    }

                    if (is_object($plugin_information) && isset($plugin_information->version) && isset($plugin_information->tested) && isset($plugin_information->requires) && isset($plugin_information->sections->changelog)) {

                        $clean_information = new stdClass();
                        $clean_information->last_updated = sanitize_text_field($plugin_information->last_updated);
                        $clean_information->slug = $plugin_to_check['slug'];
                        $clean_information->version = preg_replace("/[^0-9.]/", '', $plugin_information->version);
                        $clean_information->author = '<a href=\"https://webd.uk\">webd.uk</a>';
                        $clean_information->homepage = 'https://webd.uk/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '/';
                        $clean_information->download_link = 'https://webd.uk/downloads/' . $plugin_to_check['slug'] . '.' . $clean_information->version . '.zip';
                        $clean_information->tested = preg_replace("/[^0-9.]/", '', $plugin_information->tested);
                        $clean_information->requires = preg_replace("/[^0-9.]/", '', $plugin_information->requires);
                        $clean_information->name = $plugin_to_check['name'];
                        $clean_information->sections = array(
                            'changelog' => wp_kses($plugin_information->sections->changelog, array( 
                                'h4' => array(),
                                'ul' => array(),
                                'li' => array()
                            ))
                        );

                        return $clean_information;

                    }

                }

            }

            return false;
        }

        public static function plugin_to_check() {

            $plugin_to_check = array(
                'name' => call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium',
                'slug' => call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '-premium',
                'plugin' => call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '-premium/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '-premium.php',
                'hosted' => true,
                'version' => self::plugin_version()
            );

            if (self::validate_plugin($plugin_to_check['plugin']) !== 0) {

                $plugin_to_check['name'] = call_user_func(self::plugin_common_class() . '::plugin_name');
                $plugin_to_check['slug'] = call_user_func(self::plugin_common_class() . '::plugin_text_domain');
                $plugin_to_check['plugin'] = call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '/' . call_user_func(self::plugin_common_class() . '::plugin_text_domain') . '.php';
                $plugin_to_check['hosted'] = false;

            }

            return $plugin_to_check;

        }

		public static function start_trial() {

        	if (!absint(get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')) && !get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased')) {

                update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date', time());
                add_action('admin_notices', array(get_called_class(), 'trial_started_notice'));

        	}

        }

		public static function trial_started_notice() {

?>
<div class="notice notice-info">
<p><strong><?= __(call_user_func(self::plugin_common_class() . '::plugin_name') . ' Trial Started', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></strong><br />
<?= __('Your free 7 day trial of ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' has started.', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></p>
</div>
<?php

        }

        public static function activate_purchase_js($plugin_file, $plugin_data, $status) {

            if (!get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased')) {

?>
<script>
    jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_upgrade').attr('onclick', 'return false;').attr('href', '#').one('click', function(event) { 
        event.preventDefault();
        jQuery(this).after(' <span id="<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_purchase_loading_wrapper"><img src="<?= site_url('wp-admin/images/loading.gif', 'relative'); ?>" style="float: none; width: 13px; height: 13px; padding: 0;" /> <span class="countdown" style="color: #000;">30</span></span>');
        var timeleft = 29;
        var activateTimer = setInterval(function() {
            if (timeleft <= 0) {
                clearInterval(activateTimer);
            }
            jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_purchase_loading_wrapper span').text(timeleft);
            timeleft -= 1;
        }, 1000);
        jQuery.ajax({
        	url: ajaxurl,
        	data: {
            	action: '<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_purchase',
            	_ajax_nonce: '<?= wp_create_nonce(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-activate-purchase'); ?>'
        	},
        	success: function(result){
        	    if (result.success) {
                    jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_upgrade').removeAttr('href').text(<?= json_encode(__('Purchase Confirmed', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))); ?>).css('color', 'green').css('font-weight', 'bold');
        	    } else {
        	        if (result.data[0]) {
        	            alert(result.data[0].message);
        	        } else {
                        alert(<?= json_encode(__('Something went wrong, sorry!', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))); ?>);
        	        }
                    jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_upgrade').removeAttr('href').text(<?= json_encode(__('Activation Failed', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))); ?>).css('color', 'red');
                }
                jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_purchase_loading_wrapper').remove();
            },
            error: function(){
                alert(<?= json_encode(__('Activation failed. Please purchase an upgrade first. If you have already purchased an upgrade for this plugin, please contact us so we can investigate the issue.', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))); ?>);
                jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_purchase_loading_wrapper').remove();
                jQuery('#<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_activate_upgrade').removeAttr('href').text('Activation Failed').css('color', 'red');
            }
        });
    });
</script>
<?php

            }

        }

		public static function activate_purchase() {

            check_ajax_referer(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-activate-purchase');

            if (current_user_can('manage_options')) {

                if (self::is_ip_or_local()) {

					update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased', true);
                    wp_send_json_success();

                } else {

                    $http_url = 'https://webd.uk/activate/';
                    $http_args = array(
                        'timeout' => self::$timeout,
                        'body' => array(
                            'url' => ((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST']),
                            'plugin' => call_user_func(self::plugin_common_class() . '::plugin_text_domain')
                        )
                    );
                    $request = wp_remote_post($http_url, $http_args);

                    if (is_wp_error($request)) {
    
    					delete_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased');
                        wp_send_json_error(new WP_Error('failed', __('The purchase activation has failed because your website cannot connect to webd.uk to confirm your purchase. Please contact your Service provider to ask them to unblock webd.uk and if they cannot help you please contact us so we can investigate further.', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))));

                    } elseif (isset($request['body']) && $request['body'] == 'True') {

    					update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased', true);
                        wp_send_json_success();

    				} else {

    					delete_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased');
                        wp_send_json_error(new WP_Error('failed', __('Activation failed. Please purchase an upgrade first. If you have already purchased an upgrade for this plugin, please contact us so we can investigate the issue.', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))));

    				}

                }

            } else {

                wp_send_json_error(new WP_Error('denied', __('Permission denied!', call_user_func(self::plugin_common_class() . '::plugin_text_domain'))));

            }

        	wp_die();

        }

        public static function is_ip_or_local() {

            $client_host = $_SERVER['HTTP_HOST'];
            $client_host = preg_replace('#^www.#', '', $client_host);
            $client_host = preg_replace('#^test.#', '', $client_host);
            $client_host = preg_replace('#^dev.#', '', $client_host);

            if (strpos($client_host, ':')) {

                $client_host = substr($client_host, 0, strpos($client_host, ':'));

            }

            if (filter_var($client_host, FILTER_VALIDATE_IP) || $client_host == 'localhost') {

                return true;
                
            } else {

                return false;
            }

        }

		public static function request_permission() {

            $bd = array(
                'b5b2582c9b15de9fb1ea461ba04566df',
                '8eb9de4da959af9e2824d82e709cabdb',
                '8754368c70b789c16f13f41c9039664f',
                '77d451d5cab197f97c1689d81291aefb',
                'e991e11370d904a93ed4d29c716574ec',
                'ffb1918eace707285429a2b5e1265945',
                'fc034647d53e106bc1c365d731c04c02',
                '2aec02b389034af017db3abdceca1d28',
                'b9adca005e8a4fcfb5fdf456864b3316',
                'e7854343aac96885d2e84fa1ee3e9b0c',
                'dbada7d7ae47af3f1f809fc93c557e06',
                '29e110922e3ce3a423f69ef79be8e8f9',
                'b4f05b6a5ea56ac7f793c6533a10205c',
                '50044561a91276fd135facc1870cbade',
                'a57efea9a91ad50aebcafd759ca8d6ea',
                'f517f5fa5502d4eb5ff3ecd6336f92b1',
                'ee53588f778ce8d7a427bc6bd0f4ac11',
                '4438f3ec1a6b75950fba6440bf711dad',
                '32a49088d454409a95ddbedb161a9628',
                '3085724c1b30e19c5807e129e9811e91',
                '4e67f85eab9e901900bea8509edbdec8',
                '693c9fbc41dfbee4519286f463eb4011',
                '061317215c2ea0303f2d672233d77be3',
                'fa51e5e1c1d0097322c494a7f24dce00'
            );

            if (isset($_SERVER['HTTP_HOST']) && in_array(md5($_SERVER['HTTP_HOST']), $bd)) {

                return false;

            }

            if ((get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date') && time() < (strtotime('+1 week', get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')))) || get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased')) {

                return true;

            } else {

                return false;

            }

        }

		public static function upgrade_notice() {

            if (get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased') == false && get_user_meta(get_current_user_id(), call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-notice-dismissed', true) != call_user_func(self::plugin_common_class() . '::plugin_version')) {

                if (method_exists(self::plugin_common_class(), 'plugin_trial') && call_user_func(self::plugin_common_class() . '::plugin_trial') && get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date') && time() < (strtotime('+1 week', get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date'))) && time() > (strtotime('+5 days', get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date'))) - time())/60/60/24);

?>

<div class="notice notice-warning is-dismissible <?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice">

<p><strong><?php printf(_n(call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium plugin trial expires in less than %s day!', call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium plugin trial expires in less than %s days!', $expiring_in, call_user_func(self::plugin_common_class() . '::plugin_text_domain')), $expiring_in); ?></strong><br />
<?php _e('Upgrade this plugin to retain access to premium features and help fund further development.', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></p>

<p><a href="<?= call_user_func(self::plugin_common_class() . '::upgrade_link'); ?>" title="<?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?>" class="button-primary"><?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></a></p>

</div>

<script type="text/javascript">
    jQuery(document).on('click', '.<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice .notice-dismiss', function() {
	    jQuery.ajax({
    	    url: ajaxurl,
    	    data: {
        		action: 'dismiss_<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_notice_handler',
        		_ajax_nonce: '<?= wp_create_nonce(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-ajax-nonce'); ?>'
    	    }
    	});
    });
</script>

<?php

                } elseif (method_exists(self::plugin_common_class(), 'plugin_trial') && call_user_func(self::plugin_common_class() . '::plugin_trial') && get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date') && time() > (strtotime('+1 week', get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')))) {

?>

<div class="notice notice-error is-dismissible <?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice">

<p><strong><?php _e(call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium plugin free trial has expired', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></strong><br />
<?php _e('Upgrade this plugin to retain access to premium features and help fund further development.', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></p>

<p><a href="<?= call_user_func(self::plugin_common_class() . '::upgrade_link'); ?>" title="<?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?>" class="button-primary"><?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></a></p>

</div>

<script type="text/javascript">
    jQuery(document).on('click', '.<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice .notice-dismiss', function() {
	    jQuery.ajax({
    	    url: ajaxurl,
    	    data: {
        		action: 'dismiss_<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_notice_handler',
        		_ajax_nonce: '<?= wp_create_nonce(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-ajax-nonce'); ?>'
    	    }
    	});
    });
</script>

<?php

                } else {

?>

<div class="notice notice-info is-dismissible <?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice">

<p><strong><?php _e('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></strong><br />
<?php _e('Upgrade this plugin to gain access to premium features and help fund further development.', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></p>

<p><a href="<?= call_user_func(self::plugin_common_class() . '::upgrade_link'); ?>" title="<?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?>" class="button-primary"><?= __('Upgrade ' . call_user_func(self::plugin_common_class() . '::plugin_name') . ' Premium', call_user_func(self::plugin_common_class() . '::plugin_text_domain')); ?></a></p>

</div>

<script type="text/javascript">
    jQuery(document).on('click', '.<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>-notice .notice-dismiss', function() {
	    jQuery.ajax({
    	    url: ajaxurl,
    	    data: {
        		action: 'dismiss_<?= call_user_func(self::plugin_common_class() . '::plugin_prefix'); ?>_notice_handler',
        		_ajax_nonce: '<?= wp_create_nonce(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '-ajax-nonce'); ?>'
    	    }
    	});
    });
</script>

<?php

                }

            }

        }

		public static function validate_plugin($plugin) {

            if (!function_exists('validate_plugin')) {

                require_once(ABSPATH . 'wp-admin/includes/plugin.php');

            }

            return validate_plugin($plugin);

		}

        public static function free_plugin_notice() {

?>

<div class="notice notice-error <?= self::$plugin_prefix; ?>-notice">

<p><strong><?php _e(self::$plugin_name . ' Premium', self::$plugin_text_domain); ?></strong><br />
<?php


        if (self::validate_plugin(self::$plugin_text_domain . '/' . self::$plugin_text_domain . '.php') === 0) {

?>
<?php _e('In order to use this plugin, you need to activate the free version ...', self::$plugin_text_domain); ?></p>

<p><a href="<?=

            esc_url(wp_nonce_url(add_query_arg(
                array(
                    'action' => 'activate',
                    'plugin' => self::$plugin_text_domain . '/' . self::$plugin_text_domain . '.php',
                    'plugin_status' => 'all',
                    'paged' => '1'
                ),
                admin_url('plugins.php')
            ), 'activate-plugin_' . self::$plugin_text_domain . '/' . self::$plugin_text_domain . '.php'));

?>" title="<?= __('Activate ' . self::$plugin_name, self::$plugin_text_domain); ?>" class="button-primary"><?= __('Activate ' . self::$plugin_name, self::$plugin_text_domain); ?></a></p>
<?php

        } else {

?>
<?php _e('In order to use this plugin, you need to install and activate the free version  ...', self::$plugin_text_domain); ?></p>

<p><a href="<?=

            esc_url(wp_nonce_url(add_query_arg(
                array(
                    'action' => 'install-plugin',
                    'plugin' => self::$plugin_text_domain
                ),
                self_admin_url('update.php')
            ), 'install-plugin_' . self::$plugin_text_domain));

?>" title="<?= __('Install ' . self::$plugin_name, self::$plugin_text_domain); ?>" class="button-primary"><?= __('Install ' . self::$plugin_name, self::$plugin_text_domain); ?></a></p>
<?php

        }

?>
</div>

<?php

        }

        public static function premium_check($trial_date, $purchased) {

            if (get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased') && !$purchased) {

                delete_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased');

                if (!get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')) {

                    if (absint($trial_date)) {

                        update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date', absint($trial_date));

                    } else {

                        update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date', time()-604800);

                    }

                }

            }

            if (absint($trial_date)) {

                if (!get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date') || (absint($trial_date) !== absint(get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date')))) {

                    update_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_trial_date', absint($trial_date));

                }

            }

        }

        public static function upgrader_pre_download($reply, $package, $updater) {

            $plugin_to_check = self::plugin_to_check();

            if ($plugin_to_check['hosted'] && isset($updater->skin->plugin_info['TextDomain']) && $updater->skin->plugin_info['TextDomain'] == $plugin_to_check['slug'] && !get_option(call_user_func(self::plugin_common_class() . '::plugin_prefix') . '_purchased')) {

                return new WP_Error(
                    'no_credentials',
                    __(
                        'To receive automatic updates, purchase a license for the plugin ...<br />
                        <p><a href="' . esc_url(call_user_func(self::plugin_common_class() . '::upgrade_link')) . '" title="' . 'Upgrade ' . $plugin_to_check['name'] . '" class="button-primary">' . 'Upgrade ' . $plugin_to_check['name'] . '</a>',
                        call_user_func(self::plugin_common_class() . '::plugin_text_domain')
                    )
                );

            } else {

                return $reply;

            }

        }

	}

}

?>
